@@ -11,32 +11,27 @@ import copy
 
 from svtplay_dl.utils.urllib import quote_plus
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils import get_http_data
-from svtplay_dl.log import log
 from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.error import ServiceError
+
 
 class Sr(Service, OpenGraphThumbMixin):
     supported_domains = ['sverigesradio.se']
 
     def get(self, options):
-        error, data = self.get_urldata()
-        if error:
-            log.error("Can't get the page")
-            return
+        data = self.get_urldata()
 
         if self.exclude(options):
+            yield ServiceError("Excluding video")
             return
 
-        match = re.search(r'href="(/sida/[\.\/=a-z0-9&;\?]+\d+)" aria-label', data)
+        match = re.search(r'href="(/sida/[\.\/=a-z0-9&;\?]+playaudio=\d+)"', data)
         if not match:
-            log.error("Can't find audio info")
+            yield ServiceError("Can't find audio info")
             return
         path = quote_plus(match.group(1))
         dataurl = "http://sverigesradio.se/sida/ajax/getplayerinfo?url=%s&isios=false&playertype=html5" % path
-        error, data = get_http_data(dataurl)
-        if error:
-            log.error("Cant get stream info")
-            return
+        data = self.http.request("get", dataurl).text
         playerinfo = json.loads(data)["playerInfo"]
         for i in playerinfo["AudioSources"]:
             url = i["Url"]
