@@ -57,15 +57,14 @@ class Twitch(Service):
             data = self._get_channel(options, urlp)
         else:
             if match.group(2) in ["b", "c"]:
-                log.error("This twitch video type is unsupported")
+                yield ServiceError("This twitch video type is unsupported")
                 return
             data = self._get_archive(options, match.group(3))
         try:
             for i in data:
                 yield i
         except TwitchUrlException as e:
-            log.debug(str(e))
-            log.error("This twitch video type is unsupported")
+            yield ServiceError("This twitch video type is unsupported")
             return
 
     def _get_static_video(self, options, videoid):
